4-Class motor imagery using Pacman cues — BCI-Framework documentation

# 4-Class motor imagery using Pacman cues

class `bci_framework.default_extensions.Class_motor_imagery_Pacman.main.` `PacmanMotorImagery`

  4-Class motor imagery with Pacman cues.

  `build_trials`() → None

    Define the trials and pipeline trials.

    The trials consist (in this case) in a list of cues. The pipeline trials is a set of couples (callable, duration) that define a single trial, this list of functions are executed asynchronously and repeated for each trial.

  `on_bottom`() → None

    Start Pacman bottom walk animation.

  `on_left`() → None

    Start Pacman left walk animation.

  `on_right`() → None

    Start Pacman right walk animation.

  `on_up`() → None

    Start Pacman up walk animation.

  `soa`(*args) → None

    Stimulus onset asynchronously.

    This is a pipeline method, that explains the *args arguments.

  `start`() → None

    Start the run.

    A run consist in a consecutive pipeline trials execution.

  `stop`() → None

    Stop pipeline execution.

  `synchronizer`(value: bool) → None

    Show or hide synchronizer.

  `to_center`() → None

    Reset Pacman position.